@@ -111,7 +111,11 @@ class TestParallel
         # needs external database to run
         f.match(%r{(activerecord|activesupportcache|mongo|redis|sequel)/$}) or
         # specific exclusions below
-        f.match(%r{memory/$})
+        f.match(%r{(memory|client)/$})
+    end
+    include_tests += Dir.glob('spec/moneta/adapters/client/*_spec.rb').reject do |f|
+      # too flaky on ci.debian.net
+      f.match(%r{standard_client_tcp})
     end
     include_tests += Dir.glob('spec/moneta/adapters/memory/*_spec.rb').reject do |f|
       # ruby snappy binding missing
